@@ -1,10 +1,12 @@
 {-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE RankNTypes #-}
 
 -- | HTTP\/2 client library.
 --
 --  Example:
 --
 -- > {-# LANGUAGE OverloadedStrings #-}
+-- > {-# LANGUAGE RankNTypes #-}
 -- >
 -- > module Main where
 -- >
@@ -22,11 +24,12 @@
 -- > main :: IO ()
 -- > main = runTCPClient serverName "80" $ runHTTP2Client serverName
 -- >   where
--- >     cliconf host = ClientConfig "http" (C8.pack host) 20
+-- >     cliconf host = defaultClientConfig { authority = C8.pack host }
 -- >     runHTTP2Client host s = E.bracket (allocSimpleConfig s 4096)
 -- >                                       freeSimpleConfig
 -- >                                       (\conf -> run (cliconf host) conf client)
--- >     client sendRequest = do
+-- >     client :: Client ()
+-- >     client sendRequest _aux = do
 -- >         let req0 = requestNoBody methodGet "/" []
 -- >             client0 = sendRequest req0 $ \rsp -> do
 -- >                 print rsp
@@ -39,56 +42,106 @@
 -- >         case ex of
 -- >           Left  e  -> print (e :: HTTP2Error)
 -- >           Right () -> putStrLn "OK"
-
 module Network.HTTP2.Client (
-  -- * Runner
-    run
-  , Scheme
-  , Authority
-  -- * Runner arguments
-  , ClientConfig(..)
-  , Config(..)
-  , allocSimpleConfig
-  , freeSimpleConfig
-  -- * HTTP\/2 client
-  , Client
-  -- * Request
-  , Request
-  -- * Creating request
-  , requestNoBody
-  , requestFile
-  , requestStreaming
-  , requestBuilder
-  -- ** Trailers maker
-  , TrailersMaker
-  , NextTrailersMaker(..)
-  , defaultTrailersMaker
-  , setRequestTrailersMaker
-  -- * Response
-  , Response
-  -- ** Accessing response
-  , responseStatus
-  , responseHeaders
-  , responseBodySize
-  , getResponseBodyChunk
-  , getResponseTrailers
-  -- * Types
-  , Method
-  , Path
-  , FileSpec(..)
-  , FileOffset
-  , ByteCount
-  -- * Error
-  , HTTP2Error(..)
-  , ErrorCode(ErrorCode,NoError,ProtocolError,InternalError,FlowControlError,SettingsTimeout,StreamClosed,FrameSizeError,RefusedStream,Cancel,CompressionError,ConnectError,EnhanceYourCalm,InadequateSecurity,HTTP11Required)
-  -- * RecvN
-  , defaultReadN
-  -- * Position read for files
-  , PositionReadMaker
-  , PositionRead
-  , Sentinel(..)
-  , defaultPositionReadMaker
-  ) where
+    -- * Runner
+    run,
+
+    -- * Client configuration
+    Scheme,
+    Authority,
+    ClientConfig,
+    defaultClientConfig,
+    scheme,
+    authority,
+    cacheLimit,
+    connectionWindowSize,
+    settings,
+
+    -- * HTTP\/2 setting
+    Settings,
+    defaultSettings,
+    headerTableSize,
+    enablePush,
+    maxConcurrentStreams,
+    initialWindowSize,
+    maxFrameSize,
+    maxHeaderListSize,
+
+    -- * Common configuration
+    Config (..),
+    allocSimpleConfig,
+    freeSimpleConfig,
+
+    -- * HTTP\/2 client
+    Client,
+
+    -- * Request
+    Request,
+
+    -- * Creating request
+    requestNoBody,
+    requestFile,
+    requestStreaming,
+    requestStreamingUnmask,
+    requestBuilder,
+
+    -- ** Trailers maker
+    TrailersMaker,
+    NextTrailersMaker (..),
+    defaultTrailersMaker,
+    setRequestTrailersMaker,
+
+    -- * Response
+    Response,
+
+    -- ** Accessing response
+    responseStatus,
+    responseHeaders,
+    responseBodySize,
+    getResponseBodyChunk,
+    getResponseTrailers,
+
+    -- * Aux
+    Aux,
+    auxPossibleClientStreams,
+
+    -- * Types
+    Method,
+    Path,
+    FileSpec (..),
+    FileOffset,
+    ByteCount,
+
+    -- * Error
+    HTTP2Error (..),
+    ReasonPhrase,
+    ErrorCode (
+        ErrorCode,
+        NoError,
+        ProtocolError,
+        InternalError,
+        FlowControlError,
+        SettingsTimeout,
+        StreamClosed,
+        FrameSizeError,
+        RefusedStream,
+        Cancel,
+        CompressionError,
+        ConnectError,
+        EnhanceYourCalm,
+        InadequateSecurity,
+        HTTP11Required
+    ),
+
+    -- * RecvN
+    defaultReadN,
+
+    -- * Position read for files
+    PositionReadMaker,
+    PositionRead,
+    Sentinel (..),
+    defaultPositionReadMaker,
+) where
 
 import Data.ByteString (ByteString)
 import Data.ByteString.Builder (Builder)
@@ -96,10 +149,10 @@ import Data.IORef (readIORef)
 import Network.HTTP.Types
 
 import Network.HPACK
-import Network.HTTP2.Arch
 import Network.HTTP2.Client.Run
 import Network.HTTP2.Client.Types
 import Network.HTTP2.Frame
+import Network.HTTP2.H2 hiding (authority, scheme)
 
 ----------------------------------------------------------------
 
@@ -122,20 +175,33 @@ requestBuilder m p hdr builder = Request $ OutObj hdr' (OutBodyBuilder builder)
     hdr' = addHeaders m p hdr
 
 -- | Creating request with streaming.
-requestStreaming :: Method -> Path -> RequestHeaders
-                 -> ((Builder -> IO ()) -> IO () -> IO ())
-                 -> Request
+requestStreaming
+    :: Method
+    -> Path
+    -> RequestHeaders
+    -> ((Builder -> IO ()) -> IO () -> IO ())
+    -> Request
 requestStreaming m p hdr strmbdy = Request $ OutObj hdr' (OutBodyStreaming strmbdy) defaultTrailersMaker
   where
     hdr' = addHeaders m p hdr
 
+-- | Like 'requestStreaming', but run the action with exceptions masked
+requestStreamingUnmask
+    :: Method
+    -> Path
+    -> RequestHeaders
+    -> ((forall x. IO x -> IO x) -> (Builder -> IO ()) -> IO () -> IO ())
+    -> Request
+requestStreamingUnmask m p hdr strmbdy = Request $ OutObj hdr' (OutBodyStreamingUnmask strmbdy) defaultTrailersMaker
+  where
+    hdr' = addHeaders m p hdr
 
 addHeaders :: Method -> Path -> RequestHeaders -> RequestHeaders
 addHeaders m p hdr = (":method", m) : (":path", p) : hdr
 
 -- | Setting 'TrailersMaker' to 'Response'.
 setRequestTrailersMaker :: Request -> TrailersMaker -> Request
-setRequestTrailersMaker (Request req) tm = Request req { outObjTrailers = tm }
+setRequestTrailersMaker (Request req) tm = Request req{outObjTrailers = tm}
 
 ----------------------------------------------------------------
 
