@@ -3,38 +3,40 @@
 module Main where
 
 import Control.Exception
+import Data.ByteString (ByteString)
 import Gauge.Main
 import Network.HPACK
-import Data.ByteString (ByteString)
 
 ----------------------------------------------------------------
 
 naive, naiveh, static, statich, linear, linearh :: EncodeStrategy
-naive   = EncodeStrategy {compressionAlgo = Naive,  useHuffman = False}
-naiveh  = EncodeStrategy {compressionAlgo = Naive,  useHuffman = True}
-static  = EncodeStrategy {compressionAlgo = Static, useHuffman = False}
-statich = EncodeStrategy {compressionAlgo = Static, useHuffman = True}
-linear  = EncodeStrategy {compressionAlgo = Linear, useHuffman = False}
-linearh = EncodeStrategy {compressionAlgo = Linear, useHuffman = True}
+naive = EncodeStrategy{compressionAlgo = Naive, useHuffman = False}
+naiveh = EncodeStrategy{compressionAlgo = Naive, useHuffman = True}
+static = EncodeStrategy{compressionAlgo = Static, useHuffman = False}
+statich = EncodeStrategy{compressionAlgo = Static, useHuffman = True}
+linear = EncodeStrategy{compressionAlgo = Linear, useHuffman = False}
+linearh = EncodeStrategy{compressionAlgo = Linear, useHuffman = True}
 
 main :: IO ()
 main = do
     hdrs <- read <$> readFile "bench-hpack/headers.hs"
     hpacks <- prepare hdrs
     _ <- evaluate hpacks
-    defaultMain [
-        bgroup "HPACK decoding" [
-              bench "LinearH" $ nfIO (dec hpacks)
+    defaultMain
+        [ bgroup
+            "HPACK decoding"
+            [ bench "LinearH" $ nfIO (dec hpacks)
             ]
-      , bgroup "HPACK encoding" [
-              bench "Naive"   $ nfIO (enc naive   hdrs)
-            , bench "HaiveH"  $ nfIO (enc naiveh  hdrs)
-            , bench "Static"  $ nfIO (enc static  hdrs)
+        , bgroup
+            "HPACK encoding"
+            [ bench "Naive" $ nfIO (enc naive hdrs)
+            , bench "HaiveH" $ nfIO (enc naiveh hdrs)
+            , bench "Static" $ nfIO (enc static hdrs)
             , bench "StaticH" $ nfIO (enc statich hdrs)
-            , bench "Linear"  $ nfIO (enc linear  hdrs)
+            , bench "Linear" $ nfIO (enc linear hdrs)
             , bench "LinearH" $ nfIO (enc linearh hdrs)
             ]
-      ]
+        ]
 
 ----------------------------------------------------------------
 prepare :: [HeaderList] -> IO [ByteString]
@@ -42,8 +44,8 @@ prepare hdrs = do
     tbl <- newDynamicTableForEncoding defaultDynamicTableSize
     go tbl hdrs id
   where
-    go _    []     b = return (b [])
-    go !tbl (h:hs) b = do
+    go _ [] b = return (b [])
+    go !tbl (h : hs) b = do
         !frag <- encodeHeader linearh 4096 tbl h
         go tbl hs (b . (frag :))
 
@@ -52,8 +54,8 @@ dec hpacks = do
     tbl <- newDynamicTableForDecoding defaultDynamicTableSize 4096
     go tbl hpacks
   where
-    go _    []     = return ()
-    go !tbl (f:fs) = do
+    go _ [] = return ()
+    go !tbl (f : fs) = do
         !_ <- decodeHeader tbl f
         go tbl fs
 
@@ -62,7 +64,7 @@ enc stgy hdrs = do
     tbl <- newDynamicTableForEncoding defaultDynamicTableSize
     go tbl hdrs
   where
-    go _    []     = return ()
-    go !tbl (h:hs) = do
+    go _ [] = return ()
+    go !tbl (h : hs) = do
         !_ <- encodeHeader stgy 4096 tbl h
         go tbl hs
